@@ -24,8 +24,8 @@ class Task:
 
         Attributes:
             name (str):
-            url (Union[Unset, str]):
             uuid (Union[Unset, str]):
+            url (Union[Unset, str]):
             description (Union[Unset, str]):
             dashboard_url (Union[Unset, str]):
             infrastructure_website_url (Union[Unset, None, str]):
@@ -42,13 +42,22 @@ class Task:
             max_concurrency (Union[Unset, None, int]):
             max_age_seconds (Union[Unset, None, int]):
             default_max_retries (Union[Unset, int]):
+            max_postponed_failure_count (Union[Unset, None, int]):
+            max_postponed_missing_execution_count (Union[Unset, None, int]):
+            max_postponed_timeout_count (Union[Unset, None, int]):
+            min_missing_execution_delay_seconds (Union[Unset, None, int]):
+            postponed_failure_before_success_seconds (Union[Unset, None, int]):
+            postponed_missing_execution_before_start_seconds (Union[Unset, None, int]):
+            postponed_timeout_before_success_seconds (Union[Unset, None, int]):
+            should_clear_failure_alerts_on_success (Union[Unset, bool]):
+            should_clear_timeout_alerts_on_success (Union[Unset, bool]):
             project_url (Union[Unset, str]):
             log_query (Union[Unset, str]):
             logs_url (Union[Unset, None, str]):
             links (Union[Unset, List[Link]]):
             run_environment (Union[Unset, None, NameAndUuid]): Identifies an entity in three ways: 1. UUID; 2. Name; and 3.
                 URL.
-                When used to indentify an entity in a request method body, only one of
+                When used to identify an entity in a request method body, only one of
                 uuid and name needs to be specified. If both are present, they must
                 refer to the same entity or else the response will be a 400 error.
             execution_method_capability (Union[AwsEcsExecutionMethodCapability, UnknownExecutionMethodCapability, Unset]):
@@ -67,8 +76,8 @@ class Task:
     """
 
     name: str
-    url: Union[Unset, str] = UNSET
     uuid: Union[Unset, str] = UNSET
+    url: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
     dashboard_url: Union[Unset, str] = UNSET
     infrastructure_website_url: Union[Unset, None, str] = UNSET
@@ -85,6 +94,15 @@ class Task:
     max_concurrency: Union[Unset, None, int] = UNSET
     max_age_seconds: Union[Unset, None, int] = UNSET
     default_max_retries: Union[Unset, int] = UNSET
+    max_postponed_failure_count: Union[Unset, None, int] = UNSET
+    max_postponed_missing_execution_count: Union[Unset, None, int] = UNSET
+    max_postponed_timeout_count: Union[Unset, None, int] = UNSET
+    min_missing_execution_delay_seconds: Union[Unset, None, int] = UNSET
+    postponed_failure_before_success_seconds: Union[Unset, None, int] = UNSET
+    postponed_missing_execution_before_start_seconds: Union[Unset, None, int] = UNSET
+    postponed_timeout_before_success_seconds: Union[Unset, None, int] = UNSET
+    should_clear_failure_alerts_on_success: Union[Unset, bool] = UNSET
+    should_clear_timeout_alerts_on_success: Union[Unset, bool] = UNSET
     project_url: Union[Unset, str] = UNSET
     log_query: Union[Unset, str] = UNSET
     logs_url: Union[Unset, None, str] = UNSET
@@ -106,8 +124,8 @@ class Task:
 
     def to_dict(self) -> Dict[str, Any]:
         name = self.name
-        url = self.url
         uuid = self.uuid
+        url = self.url
         description = self.description
         dashboard_url = self.dashboard_url
         infrastructure_website_url = self.infrastructure_website_url
@@ -124,6 +142,15 @@ class Task:
         max_concurrency = self.max_concurrency
         max_age_seconds = self.max_age_seconds
         default_max_retries = self.default_max_retries
+        max_postponed_failure_count = self.max_postponed_failure_count
+        max_postponed_missing_execution_count = self.max_postponed_missing_execution_count
+        max_postponed_timeout_count = self.max_postponed_timeout_count
+        min_missing_execution_delay_seconds = self.min_missing_execution_delay_seconds
+        postponed_failure_before_success_seconds = self.postponed_failure_before_success_seconds
+        postponed_missing_execution_before_start_seconds = self.postponed_missing_execution_before_start_seconds
+        postponed_timeout_before_success_seconds = self.postponed_timeout_before_success_seconds
+        should_clear_failure_alerts_on_success = self.should_clear_failure_alerts_on_success
+        should_clear_timeout_alerts_on_success = self.should_clear_timeout_alerts_on_success
         project_url = self.project_url
         log_query = self.log_query
         logs_url = self.logs_url
@@ -192,10 +219,10 @@ class Task:
                 "name": name,
             }
         )
-        if url is not UNSET:
-            field_dict["url"] = url
         if uuid is not UNSET:
             field_dict["uuid"] = uuid
+        if url is not UNSET:
+            field_dict["url"] = url
         if description is not UNSET:
             field_dict["description"] = description
         if dashboard_url is not UNSET:
@@ -232,6 +259,26 @@ class Task:
             field_dict["max_age_seconds"] = max_age_seconds
         if default_max_retries is not UNSET:
             field_dict["default_max_retries"] = default_max_retries
+        if max_postponed_failure_count is not UNSET:
+            field_dict["max_postponed_failure_count"] = max_postponed_failure_count
+        if max_postponed_missing_execution_count is not UNSET:
+            field_dict["max_postponed_missing_execution_count"] = max_postponed_missing_execution_count
+        if max_postponed_timeout_count is not UNSET:
+            field_dict["max_postponed_timeout_count"] = max_postponed_timeout_count
+        if min_missing_execution_delay_seconds is not UNSET:
+            field_dict["min_missing_execution_delay_seconds"] = min_missing_execution_delay_seconds
+        if postponed_failure_before_success_seconds is not UNSET:
+            field_dict["postponed_failure_before_success_seconds"] = postponed_failure_before_success_seconds
+        if postponed_missing_execution_before_start_seconds is not UNSET:
+            field_dict[
+                "postponed_missing_execution_before_start_seconds"
+            ] = postponed_missing_execution_before_start_seconds
+        if postponed_timeout_before_success_seconds is not UNSET:
+            field_dict["postponed_timeout_before_success_seconds"] = postponed_timeout_before_success_seconds
+        if should_clear_failure_alerts_on_success is not UNSET:
+            field_dict["should_clear_failure_alerts_on_success"] = should_clear_failure_alerts_on_success
+        if should_clear_timeout_alerts_on_success is not UNSET:
+            field_dict["should_clear_timeout_alerts_on_success"] = should_clear_timeout_alerts_on_success
         if project_url is not UNSET:
             field_dict["project_url"] = project_url
         if log_query is not UNSET:
@@ -274,10 +321,10 @@ class Task:
         d = src_dict.copy()
         name = d.pop("name")
 
-        url = d.pop("url", UNSET)
-
         uuid = d.pop("uuid", UNSET)
 
+        url = d.pop("url", UNSET)
+
         description = d.pop("description", UNSET)
 
         dashboard_url = d.pop("dashboard_url", UNSET)
@@ -314,6 +361,26 @@ class Task:
 
         default_max_retries = d.pop("default_max_retries", UNSET)
 
+        max_postponed_failure_count = d.pop("max_postponed_failure_count", UNSET)
+
+        max_postponed_missing_execution_count = d.pop("max_postponed_missing_execution_count", UNSET)
+
+        max_postponed_timeout_count = d.pop("max_postponed_timeout_count", UNSET)
+
+        min_missing_execution_delay_seconds = d.pop("min_missing_execution_delay_seconds", UNSET)
+
+        postponed_failure_before_success_seconds = d.pop("postponed_failure_before_success_seconds", UNSET)
+
+        postponed_missing_execution_before_start_seconds = d.pop(
+            "postponed_missing_execution_before_start_seconds", UNSET
+        )
+
+        postponed_timeout_before_success_seconds = d.pop("postponed_timeout_before_success_seconds", UNSET)
+
+        should_clear_failure_alerts_on_success = d.pop("should_clear_failure_alerts_on_success", UNSET)
+
+        should_clear_timeout_alerts_on_success = d.pop("should_clear_timeout_alerts_on_success", UNSET)
+
         project_url = d.pop("project_url", UNSET)
 
         log_query = d.pop("log_query", UNSET)
@@ -422,8 +489,8 @@ class Task:
 
         task = cls(
             name=name,
-            url=url,
             uuid=uuid,
+            url=url,
             description=description,
             dashboard_url=dashboard_url,
             infrastructure_website_url=infrastructure_website_url,
@@ -440,6 +507,15 @@ class Task:
             max_concurrency=max_concurrency,
             max_age_seconds=max_age_seconds,
             default_max_retries=default_max_retries,
+            max_postponed_failure_count=max_postponed_failure_count,
+            max_postponed_missing_execution_count=max_postponed_missing_execution_count,
+            max_postponed_timeout_count=max_postponed_timeout_count,
+            min_missing_execution_delay_seconds=min_missing_execution_delay_seconds,
+            postponed_failure_before_success_seconds=postponed_failure_before_success_seconds,
+            postponed_missing_execution_before_start_seconds=postponed_missing_execution_before_start_seconds,
+            postponed_timeout_before_success_seconds=postponed_timeout_before_success_seconds,
+            should_clear_failure_alerts_on_success=should_clear_failure_alerts_on_success,
+            should_clear_timeout_alerts_on_success=should_clear_timeout_alerts_on_success,
             project_url=project_url,
             log_query=log_query,
             logs_url=logs_url,
